# Identity provider details

This directory contains identity provider data and examples that are copied
to the Annalist configuration directory as part of the Annalist software 
installation/upgrade procedure.

